Module state_manager

Module state_manager 

Multi-location state management for tamper resistance

This module stores license state in multiple locations to detect deletion attacks on clock manipulation detection.

Security Witness Pattern

This module provides attestation about state file integrity. It detects and reports issues but does not automatically repair them. A policy layer should decide how to respond.

Structs

StateManager
Manages license state across multiple storage locations
StateObservations
Observations about state file storage locations.