pub struct CryptoRegistry;Expand description
Registry for cryptographic algorithms
Provides lookup functionality to get algorithms by their identifier. This enables runtime selection of algorithms based on license metadata.
Implementations
Sourceimpl CryptoRegistry
impl CryptoRegistry
Sourcepub fn get_signature_algorithm(
algorithm_id: &str,
) -> Result<&'static dyn SignatureAlgorithm>
pub fn get_signature_algorithm( algorithm_id: &str, ) -> Result<&'static dyn SignatureAlgorithm>
Get a signature algorithm by its identifier
Sourcepub fn supported_signature_algorithms() -> Vec<&'static str>
pub fn supported_signature_algorithms() -> Vec<&'static str>
Get a list of all supported signature algorithm IDs
Sourcepub fn is_signature_algorithm_supported(algorithm_id: &str) -> bool
pub fn is_signature_algorithm_supported(algorithm_id: &str) -> bool
Check if a signature algorithm is supported
Sourcepub fn default_signature_algorithm() -> &'static dyn SignatureAlgorithm
pub fn default_signature_algorithm() -> &'static dyn SignatureAlgorithm
Get the default signature algorithm (RSA-SHA256 for backward compatibility)
Sourcepub fn is_post_quantum_available() -> bool
pub fn is_post_quantum_available() -> bool
Check if post-quantum algorithms are available
Sourcepub fn post_quantum_signature_algorithms() -> Vec<&'static str>
pub fn post_quantum_signature_algorithms() -> Vec<&'static str>
Get a list of post-quantum signature algorithm IDs
Sourcepub fn classical_signature_algorithms() -> Vec<&'static str>
pub fn classical_signature_algorithms() -> Vec<&'static str>
Get a list of classical (non-PQ) signature algorithm IDs
Sourcepub fn hybrid_signature_algorithms() -> Vec<&'static str>
pub fn hybrid_signature_algorithms() -> Vec<&'static str>
Get a list of hybrid signature algorithm IDs
Sourcepub fn recommended_algorithm() -> &'static dyn SignatureAlgorithm
pub fn recommended_algorithm() -> &'static dyn SignatureAlgorithm
Get the recommended algorithm for maximum security