pub struct KeyPair {
pub public_key: RsaPublicKey,
/* private fields */
}Expand description
RSA key pair for license signing
Fields
public_key: RsaPublicKeyImplementations
Sourceimpl KeyPair
impl KeyPair
Sourcepub fn private_key(&self) -> &RsaPrivateKey
pub fn private_key(&self) -> &RsaPrivateKey
Get a reference to the private key
Sourcepub fn into_private_key(self) -> RsaPrivateKey
pub fn into_private_key(self) -> RsaPrivateKey
Consume the key pair and return the private key
Sourcepub fn export_private_pem(&self) -> Result<String>
pub fn export_private_pem(&self) -> Result<String>
Export the private key as PEM string
Sourcepub fn export_public_pem(&self) -> Result<String>
pub fn export_public_pem(&self) -> Result<String>
Export the public key as PEM string
Sourcepub fn save_to_files(
&self,
private_path: &Path,
public_path: &Path,
) -> Result<()>
pub fn save_to_files( &self, private_path: &Path, public_path: &Path, ) -> Result<()>
Save the key pair to files
Sourcepub fn load_from_files(private_path: &Path, public_path: &Path) -> Result<Self>
pub fn load_from_files(private_path: &Path, public_path: &Path) -> Result<Self>
Load a key pair from files
On Unix, this checks that the private key file is not readable by group/other.